@@ -4,7 +4,7 @@ from vista_api_client.api_resources.api_resource import ApiResource, HttpMethods
 
 class Admin(ApiResource):
     def create_branch(self, branch):
-        return self.dispatch('/v1/branches', HttpMethods.POST, {
+        return self.dispatch('/v1/companies/branches', HttpMethods.POST, {
             'branch': branch,
         })
 
